[FFmpeg-devel] [PATCH] - cosmetic: the decklink_dec* files are used for input from the decklink cards. update the header to reflect that

Felt, Patrick Patrick.Felt at echostar.com
Tue Aug 2 21:44:14 EEST 2016


This is a cosmetic patch only to update the header of decklink files to be indicative of data flow direction.


---
libavdevice/decklink_dec.cpp | 4 ++--
libavdevice/decklink_dec.h   | 2 +-
libavdevice/decklink_dec_c.c | 2 +-
3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/libavdevice/decklink_dec.h b/libavdevice/decklink_dec.h
index c02344e..9b71870 100644
--- a/libavdevice/decklink_dec.h
+++ b/libavdevice/decklink_dec.h
@@ -1,5 +1,5 @@
/*
- * Blackmagic DeckLink output
+ * Blackmagic DeckLink input
  * Copyright (c) 2013-2014 Ramiro Polla
  *
  * This file is part of FFmpeg.
diff --git a/libavdevice/decklink_dec_c.c b/libavdevice/decklink_dec_c.c
index 523be66..56bc439 100644
--- a/libavdevice/decklink_dec_c.c
+++ b/libavdevice/decklink_dec_c.c
@@ -1,5 +1,5 @@
/*
- * Blackmagic DeckLink output
+ * Blackmagic DeckLink input
  * Copyright (c) 2014 Deti Fliegl
  *
  * This file is part of FFmpeg.
diff --git a/libavdevice/decklink_dec.cpp b/libavdevice/decklink_dec.cpp
index fcb024e..fc81d4d 100644
--- a/libavdevice/decklink_dec.cpp
+++ b/libavdevice/decklink_dec.cpp
@@ -1,5 +1,5 @@
/*
  * Blackmagic DeckLink output
  * Copyright (c) 2013-2014 Luca Barbato, Deti Fliegl
  *
  * This file is part of FFmpeg.
@@ -524,7 +524,7 @@ av_cold int ff_decklink_read_header(AVFormatContext *avctx)

     /* Get input device. */
     if (ctx->dl->QueryInterface(IID_IDeckLinkInput, (void **) &ctx->dli) != S_OK) {
-        av_log(avctx, AV_LOG_ERROR, "Could not open output device from '%s'\n",
+        av_log(avctx, AV_LOG_ERROR, "Could not open input device from '%s'\n",
                avctx->filename);
         ret = AVERROR(EIO);
         goto error;
@@ -1,5 +1,5 @@
/*
- * Blackmagic DeckLink output
+ * Blackmagic DeckLink input
  * Copyright (c) 2013-2014 Luca Barbato, Deti Fliegl
  *
--
1.8.3.1


More information about the ffmpeg-devel mailing list